@@ -54,20 +54,20 @@ def test_modifier_method(schema, jp_event_logger, jp_read_emitted_events):
     assert output["username"] == "<masked>"
 
 
-def test_bad_modifier_functions(jp_event_logger, schema: EventSchema):
+def test_bad_modifier_functions(jp_event_logger: EventLogger, schema: EventSchema) -> None:
     event_logger = jp_event_logger
 
     def modifier_with_extra_args(schema_id: str, data: dict, unknown_arg: dict) -> dict:
         return data
 
     with pytest.raises(ModifierError):
-        event_logger.add_modifier(modifier=modifier_with_extra_args)
+        event_logger.add_modifier(modifier=modifier_with_extra_args)  # type:ignore[arg-type]
 
     # Ensure no modifier was added.
     assert len(event_logger._modifiers[schema.id]) == 0
 
 
-def test_bad_modifier_method(jp_event_logger, schema: EventSchema):
+def test_bad_modifier_method(jp_event_logger: EventLogger, schema: EventSchema) -> None:
     event_logger = jp_event_logger
 
     class Redactor:
@@ -77,7 +77,7 @@ def test_bad_modifier_method(jp_event_logger, schema: EventSchema):
     redactor = Redactor()
 
     with pytest.raises(ModifierError):
-        event_logger.add_modifier(modifier=redactor.redact)
+        event_logger.add_modifier(modifier=redactor.redact)  # type:ignore[arg-type]
 
     # Ensure no modifier was added
     assert len(event_logger._modifiers[schema.id]) == 0
@@ -90,7 +90,7 @@ def test_modifier_without_annotations():
         return event
 
     with pytest.raises(ModifierError):
-        logger.add_modifier(modifier=modifier_with_extra_args)
+        logger.add_modifier(modifier=modifier_with_extra_args)  # type:ignore[arg-type]
 
 
 def test_remove_modifier(schema, jp_event_logger, jp_read_emitted_events):
